enumSymbolKind
enum SymbolKind: string
Public API: explicitly declared with
@visibility public.The three spellings a grammar symbol may have.
An identifier names a token or a nonterminal, a character literal such as '+' is a token that stands for itself, and a string such as "end of file" is a token spelled by its alias.
\BisonParser\Ast\SymbolKind::CharLiteral->value // => 'char'Cases
case Identifier = 'identifier'case CharLiteral = 'char'case String = 'string'Test cases 38
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 37
TreeDumper::symbolcallsCodePropsTest::testLocationcallsStartTest::testLocationcallsPrecedenceDeclarationTest::testLocationcallsSymbolDeclarationTest::testLocationcallsSymbolEntryTest::testAliascallsGrammarFileTest::testAllDeclarationscallsGrammarFileTest::testRulescallsAlternativeTest::testSymbolscallsPrecItemTest::testLocationcallsRuleTest::testAlternativescallsSymbolItemTest::testLocationcallsSymbolTest::testIsIdentifiercallsBisonGrammarCompilerTestcallsBisonGrammarReaderTestcallsParserTestcallsDeclarationPrinterTest::testEntriescallsDeclarationPrinterTest::testPrintcallsDeclarationPrinterTest::testPropscallsDeclarationPrinterTest::testTargetscallsPrinterTest::testAlternativecallsPrinterTest::testPrintcallsPrinterTest::testRulecallsRhsPrinterTest::testPrintcallsSymbolPrinterTest::testSymbolcallsDeclarationParserTestcallsGrammarParserTestcallsRuleParserTest::testCheckEmptycallsSymbolListParserTest::testDescribecallsSymbolListParserTest::testEntriescallsSymbolListParserTest::testEntriesPassOverALineBetweenEntriescallsSymbolListParserTest::testEntriesRejectASymbolOfAnotherKindcallsSymbolListParserTest::testEntriesRejectsAnEmptyListcallsSymbolListParserTest::testEntriesRejectsATagWithoutASymbolcallsSymbolListParserTest::testKindcallsSymbolListParserTest::testPrecedenceDeclarationscallsSymbolListParserTest::testSymbolcalls
Relations
Constant reads 22
- class-const BisonParser\Ast\Symbol::isIdentifier() packages/bison-parser/src/Ast/Symbol.php:47
- class-const BisonParser\Printer\SymbolPrinter::symbol() packages/bison-parser/src/Printer/SymbolPrinter.php:40
- class-const BisonParser\Printer\SymbolPrinter::symbol() packages/bison-parser/src/Printer/SymbolPrinter.php:41
- class-const BisonParser\Printer\SymbolPrinter::symbol() packages/bison-parser/src/Printer/SymbolPrinter.php:42
- class-const BisonParser\Syntax\SymbolListParser::tokenDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:38
- class-const BisonParser\Syntax\SymbolListParser::tokenDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:38
- class-const BisonParser\Syntax\SymbolListParser::ntermDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:52
- class-const BisonParser\Syntax\SymbolListParser::precedenceDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:66
- class-const BisonParser\Syntax\SymbolListParser::precedenceDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:66
- class-const BisonParser\Syntax\SymbolListParser::precedenceDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:66
- class-const BisonParser\Syntax\SymbolListParser::typeDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:80
- class-const BisonParser\Syntax\SymbolListParser::typeDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:80
- class-const BisonParser\Syntax\SymbolListParser::typeDeclarations() packages/bison-parser/src/Syntax/SymbolListParser.php:80
- class-const BisonParser\Syntax\SymbolListParser::symbol() packages/bison-parser/src/Syntax/SymbolListParser.php:255
- class-const BisonParser\Syntax\SymbolListParser::kind() packages/bison-parser/src/Syntax/SymbolListParser.php:268
- class-const BisonParser\Syntax\SymbolListParser::kind() packages/bison-parser/src/Syntax/SymbolListParser.php:271
- class-const BisonParser\Syntax\SymbolListParser::kind() packages/bison-parser/src/Syntax/SymbolListParser.php:274
- class-const BisonParser\Syntax\SymbolListParser::describe() packages/bison-parser/src/Syntax/SymbolListParser.php:286
- class-const BisonParser\Syntax\SymbolListParser::describe() packages/bison-parser/src/Syntax/SymbolListParser.php:286
- class-const BisonParser\Syntax\SymbolListParser::describe() packages/bison-parser/src/Syntax/SymbolListParser.php:286
- class-const SqlFaker\Compiler\Bison\BisonGrammarCompiler::symbols() packages/sql-faker/src/Compiler/Bison/BisonGrammarCompiler.php:121
- class-const SqlFaker\Compiler\Bison\BisonGrammarCompiler::symbols() packages/sql-faker/src/Compiler/Bison/BisonGrammarCompiler.php:123